@@ -141,6 +141,16 @@ def cmd_remove(root, *args):
     return root
 
 
+@register_command('remove_one')
+def cmd_remove(root, *args):
+    for selector in args:
+        xpath = parse_selector(selector)
+        els = root.xpath(xpath)
+        if els:
+            remove_preserve_tail(els[0])
+    return root
+
+
 @register_command('eval')
 def cmd_eval(root, statement):
     return eval(statement.replace('$root', 'root'))
@@ -237,7 +247,7 @@ def cmd_inner_text(root):
 def cmd_inner_html(root):
     outer_html = tostring(root)
     inner_html = outer_html[outer_html.find(b'>') + 1:outer_html.rfind(b'<')]
-    return fromstring(inner_html) if inner_html else fromstring('<p></p>')
+    return fromstring(inner_html) if inner_html.strip() else fromstring('<p></p>')
 
 
 @register_command('parse_html')
